summaryrefslogtreecommitdiffstats
path: root/testing/raptor/mach_commands.py
diff options
context:
space:
mode:
Diffstat (limited to 'testing/raptor/mach_commands.py')
-rw-r--r--testing/raptor/mach_commands.py22
1 files changed, 12 insertions, 10 deletions
diff --git a/testing/raptor/mach_commands.py b/testing/raptor/mach_commands.py
index b1c5002efc..14ffb1caf2 100644
--- a/testing/raptor/mach_commands.py
+++ b/testing/raptor/mach_commands.py
@@ -68,6 +68,7 @@ class RaptorRunner(MozbuildObject):
self.browsertime_visualmetrics = kwargs["browsertime_visualmetrics"]
self.browsertime_node = kwargs["browsertime_node"]
self.clean = kwargs["clean"]
+ self.screenshot_on_failure = kwargs["screenshot_on_failure"]
if Conditions.is_android(self) or kwargs["app"] in ANDROID_BROWSERS:
self.binary_path = None
@@ -122,6 +123,7 @@ class RaptorRunner(MozbuildObject):
"browsertime_node": self.browsertime_node,
"mozbuild_path": get_state_dir(),
"clean": self.clean,
+ "screenshot_on_failure": self.screenshot_on_failure,
}
sys.path.insert(0, os.path.join(self.topsrcdir, "tools", "browsertime"))
@@ -267,7 +269,7 @@ class RaptorRunner(MozbuildObject):
def setup_node(command_context):
"""Fetch the latest node-16 binary and install it into the .mozbuild directory."""
import platform
from mozbuild.artifact_commands import artifact_toolchain
@@ -276,11 +278,11 @@ def setup_node(command_context):
print("Setting up node for browsertime...")
state_dir = get_state_dir()
- cache_path = os.path.join(state_dir, "browsertime", "node-16")
+ cache_path = os.path.join(state_dir, "browsertime", "node-18")
def __check_for_node():
# Check standard locations first
- node_exe = find_node_executable(min_version=Version("16.0.0"))
+ node_exe = find_node_executable(min_version=Version("18.0.0"))
if node_exe and (node_exe[0] is not None):
return node_exe[0]
if not os.path.exists(cache_path):
@@ -293,14 +295,14 @@ def setup_node(command_context):
node_exe_path = os.path.join(
state_dir,
"browsertime",
- "node-16",
+ "node-18",
"node",
)
else:
node_exe_path = os.path.join(
state_dir,
"browsertime",
- "node-16",
+ "node-18",
"node",
"bin",
)
@@ -313,7 +315,7 @@ def setup_node(command_context):
node_exe = __check_for_node()
if node_exe is None:
- toolchain_job = "{}-node-16"
+ toolchain_job = "{}-node-18"
plat = platform.system()
if plat == "Windows":
toolchain_job = toolchain_job.format("win64")
@@ -326,7 +328,7 @@ def setup_node(command_context):
toolchain_job = toolchain_job.format("linux64")
print(
- "Downloading Node v16 from Taskcluster toolchain {}...".format(
+ "Downloading Node v18 from Taskcluster toolchain {}...".format(
toolchain_job
)
)
@@ -351,11 +353,11 @@ def setup_node(command_context):
node_exe = __check_for_node()
if node_exe is None:
- raise Exception("Could not find Node v16 binary for Raptor-Browsertime")
+ raise Exception("Could not find Node v18 binary for Raptor-Browsertime")
- print("Finished downloading Node v16 from Taskcluster")
+ print("Finished downloading Node v18 from Taskcluster")
- print("Node v16+ found at: %s" % node_exe)
+ print("Node v18+ found at: %s" % node_exe)
return node_exe
@@ -267,7 +269,7 @@ class RaptorRunner(MozbuildObject):
def setup_node(command_context):
- """Fetch the latest node-16 binary and install it into the .mozbuild directory."""
+ """Fetch the latest node-18 binary and install it into the .mozbuild directory."""
import platform
from mozbuild.artifact_commands import artifact_toolchain